#ifndef CONFIG_H
#define CONFIG_H
#include <json-c/json_object.h>

typedef struct config_container
{
    json_object* json;
} CONFIGURATION;

const char* config_to_formatted_json_string(const CONFIGURATION* config);
CONFIGURATION* config_create(void);
int config_clear(const CONFIGURATION* config);

CONFIGURATION* config_load_from_path(const char* path);
int config_save_to_path(const CONFIGURATION* config, const char* path);
int config_remove(const CONFIGURATION* config, const char* key);

int config_set_json(const CONFIGURATION* config, const char* key, json_object* json_value_object);

int config_set_string(const CONFIGURATION* config, const char* key, const char* str_value);
int config_set_int(const CONFIGURATION* config, const char* key, size_t int_value);
int config_set_uint(const CONFIGURATION* config, const char* key, uint64_t int_value);
int config_set_double(const CONFIGURATION* config, const char* key, double double_value);

json_object* config_get_json(const CONFIGURATION* config, const char* key);

// The returning value need to be free'd with the 'free()' function!
char* config_get_string(const CONFIGURATION* config, const char* key);
int64_t config_get_int(const CONFIGURATION* config, const char* key);
uint64_t config_get_uint(const CONFIGURATION* config, const char* key);
double config_get_double(const CONFIGURATION* config, const char* key);

#endif //CONFIG_H
